Interface: ArcOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ArcOptions

## # Hierarchy

- `CommonElementOptions`

  ↳ `ArcOptions`

## # Properties

### # backgroundColor

• backgroundColor: `Color`

#### # Inherited from

CommonElementOptions.backgroundColor

#### # Defined in

index.esm.d.ts:1696
(opens new window)

### # borderAlign

• borderAlign: `"center"` | `"inner"`

Arc stroke alignment.

#### # Defined in

index.esm.d.ts:1732
(opens new window)

### # borderColor

• borderColor: `Color`

#### # Inherited from

CommonElementOptions.borderColor

#### # Defined in

index.esm.d.ts:1695
(opens new window)

### # borderJoinStyle

• borderJoinStyle: `CanvasLineJoin`

Line join style. See MDN. Default is 'round' when `borderAlign` is 'inner', else 'bevel'.

#### # Defined in

index.esm.d.ts:1737
(opens new window)

### # borderRadius

• borderRadius: `number` | `ArcBorderRadius`

Sets the border radius for arcs

`default` 0

#### # Defined in

index.esm.d.ts:1743
(opens new window)

### # borderWidth

• borderWidth: `number`

#### # Inherited from

CommonElementOptions.borderWidth

#### # Defined in

index.esm.d.ts:1694
(opens new window)

### # circular

• circular: `boolean`

If false, Arc will be flat.

`default` true

#### # Defined in

index.esm.d.ts:1754
(opens new window)

### # offset

• offset: `number`

Arc offset (in pixels).

#### # Defined in

index.esm.d.ts:1748
(opens new window)